>From 6b60197d2fe62391a722f6fd23ff753cd2c37717 Mon Sep 17 00:00:00 2001
From: Denis 'GNUtoo' Carikli <GNUtoo@no-log.org>
Date: Sat, 16 Feb 2013 17:34:09 +0100
Subject: [PATCH] Add i915 VGA Stub.

Signed-off-by: Denis 'GNUtoo' Carikli <GNUtoo@no-log.org>
---
 Makefile         |  2 +-
 vgasrc/Kconfig   |  4 ++++
 vgasrc/i915vga.c | 36 ++++++++++++++++++++++++++++++++++++
 vgasrc/vgahw.h   |  2 ++
 4 files changed, 43 insertions(+), 1 deletion(-)
 create mode 100644 vgasrc/i915vga.c

diff --git a/Makefile b/Makefile
index fb0c89b..3438492 100644
--- a/Makefile
+++ b/Makefile
@@ -177,7 +177,7 @@ $(OUT)bios.bin.elf $(OUT)bios.bin: $(OUT)rom.o tools/checkrom.py
 SRCVGA=src/output.c src/util.c src/pci.c \
     vgasrc/vgabios.c vgasrc/vgafb.c vgasrc/vgafonts.c vgasrc/vbe.c \
     vgasrc/stdvga.c vgasrc/stdvgamodes.c vgasrc/stdvgaio.c \
-    vgasrc/clext.c vgasrc/bochsvga.c vgasrc/geodevga.c
+    vgasrc/clext.c vgasrc/bochsvga.c vgasrc/geodevga.c vgasrc/i915vga.c
 
 CFLAGS16VGA = $(CFLAGS16INC) -Isrc
 
diff --git a/vgasrc/Kconfig b/vgasrc/Kconfig
index 0901c04..24eacc7 100644
--- a/vgasrc/Kconfig
+++ b/vgasrc/Kconfig
@@ -41,6 +41,10 @@ menu "VGA ROM"
             bool "GeodeLX"
             help
                 Build support for Geode LX vga.
+        config VGA_I915
+            bool "I915"
+            help
+                Build support for Intel i915 vga.
     endchoice
 
     choice
diff --git a/vgasrc/i915vga.c b/vgasrc/i915vga.c
new file mode 100644
index 0000000..bbf2d22
--- /dev/null
+++ b/vgasrc/i915vga.c
@@ -0,0 +1,36 @@
+// Intel i915 VGA functions
+//
+// Copyright (C) 2013 Denis 'GNUtoo' Carikli
+//
+// This file may be distributed under the terms of the GNU LGPLv3 license.
+
+#include "farptr.h" // SET_FARVAR
+#include "biosvar.h" // GET_BDA
+#include "vgabios.h" // VGAREG_*
+#include "util.h" // memset
+#include "stdvga.h" // stdvga_crtc_write
+#include "pci.h" // pci_config_readl
+#include "pci_regs.h" // PCI_BASE_ADDRESS_0
+
+
+/****************************************************************
+ * Helper functions
+ ****************************************************************/
+
+/****************************************************************
+* Init Functions
+****************************************************************/
+
+int i915vga_setup(void)
+{
+    int ret = stdvga_setup();
+    if (ret)
+        return ret;
+
+    dprintf(1, "i915vga_setup: VGA init...\n");
+    /*
+     *  insert initialization here 
+     */
+
+    return 0;
+}
diff --git a/vgasrc/vgahw.h b/vgasrc/vgahw.h
index f69a5ac..60feed3 100644
--- a/vgasrc/vgahw.h
+++ b/vgasrc/vgahw.h
@@ -41,6 +41,8 @@ static inline int vgahw_setup(void) {
         return bochsvga_setup();
     if (CONFIG_VGA_GEODEGX2 || CONFIG_VGA_GEODELX)
         return geodevga_setup();
+    if (CONFIG_VGA_I915)
+        return i915vga_setup();
     return stdvga_setup();
 }
 
-- 
1.8.1.3

